@@ -19,6 +19,7 @@
 
 #include "SaveOptionsPage.h"
 
+#include "SpectacleCommon.h"
 #include "SpectacleConfig.h"
 #include "ExportManager.h"
 
@@ -28,7 +29,6 @@
 #include <QLineEdit>
 #include <QLabel>
 #include <QFormLayout>
-#include <QGroupBox>
 #include <QHBoxLayout>
 #include <QComboBox>
 #include <QImageWriter>
@@ -70,7 +70,7 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
     mQualitySlider->setSliderPosition(SpectacleConfig::instance()->compressionQuality());
     mQualitySlider->setTickPosition(QSlider::TicksBelow);
     mQualitySlider->setTracking(true);
-    connect(mQualitySlider, &QSlider::valueChanged, [=](int value) {
+    connect(mQualitySlider, &QSlider::valueChanged, this, [=](int value) {
         qualityValue->setNum(value);
         markDirty();
     });
@@ -93,9 +93,10 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
     QHBoxLayout *saveFieldLayout = new QHBoxLayout;
     mSaveNameFormat = new QLineEdit;
     connect(mSaveNameFormat, &QLineEdit::textEdited, this, &SaveOptionsPage::markDirty);
-    connect(mSaveNameFormat, &QLineEdit::textEdited, [&](const QString &newText) {
+    connect(mSaveNameFormat, &QLineEdit::textEdited, this, [&](const QString &newText) {
         QString fmt;
-        Q_FOREACH(auto item, QImageWriter::supportedImageFormats()) {
+        const auto imageFormats = QImageWriter::supportedImageFormats();
+        for (const auto &item : imageFormats) {
             fmt = QString::fromLocal8Bit(item);
             if (newText.endsWith(QLatin1Char('.') + fmt, Qt::CaseInsensitive)) {
                 QString txtCopy = newText;
@@ -112,7 +113,8 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
     mSaveImageFormat = new QComboBox;
     mSaveImageFormat->addItems([&](){
         QStringList items;
-        Q_FOREACH(auto fmt, QImageWriter::supportedImageFormats()) {
+        const auto formats = QImageWriter::supportedImageFormats();
+        for (const auto &fmt : formats) {
             items.append(QString::fromLocal8Bit(fmt).toUpper());
         }
         return items;
@@ -131,9 +133,8 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
     );
     for (auto option = ExportManager::filenamePlaceholders.cbegin();
          option != ExportManager::filenamePlaceholders.cend(); ++option) {
-        helpText += QStringLiteral("<a href=%1>%1</a>: %2<br>").arg(
-                option.key(),
-                i18nc("A placeholder in the user configurable filename will replaced by the specified value", option.value()));
+        helpText += QStringLiteral("<a href=%1>%1</a>: %2<br>").arg(option.key(),
+                                                                    option.value().toString());
     }
     helpText += QStringLiteral("<a href='/'>/</a>: ") + i18n("To save to a sub-folder");
     helpText += QStringLiteral("</blockquote>");
@@ -141,7 +142,7 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
     fmtHelpText->setWordWrap(true);
     fmtHelpText->setTextFormat(Qt::RichText);
     fmtHelpText->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
-    connect(fmtHelpText, &QLabel::linkActivated, [this](const QString& placeholder) {
+    connect(fmtHelpText, &QLabel::linkActivated, this, [this](const QString& placeholder) {
         mSaveNameFormat->insert(placeholder);
     });
     mainLayout->addWidget(fmtHelpText);
@@ -163,7 +164,7 @@ void SaveOptionsPage::saveChanges()
 
     // save the data
 
-    cfgManager->setDefaultSaveLocation(mUrlRequester->url().toDisplayString(QUrl::PreferLocalFile));
+    cfgManager->setDefaultSaveLocation(mUrlRequester->url());
     cfgManager->setAutoSaveFilenameFormat(mSaveNameFormat->text());
     cfgManager->setSaveImageFormat(mSaveImageFormat->currentText().toLower());
     cfgManager->setCopySaveLocationToClipboard(mCopyPathToClipboard->checkState() == Qt::Checked);
@@ -183,7 +184,7 @@ void SaveOptionsPage::resetChanges()
     // read in the data
 
     mSaveNameFormat->setText(cfgManager->autoSaveFilenameFormat());
-    mUrlRequester->setUrl(QUrl::fromUserInput(cfgManager->defaultSaveLocation()));
+    mUrlRequester->setUrl(cfgManager->defaultSaveLocation());
     mCopyPathToClipboard->setChecked(cfgManager->copySaveLocationToClipboard());
     mQualitySlider->setSliderPosition(cfgManager->compressionQuality());
 
@@ -203,20 +204,21 @@ void SaveOptionsPage::resetChanges()
 
 void SaveOptionsPage::updateFilenamePreview()
 {
-    ExportManager *exportManager = ExportManager::instance();
-    exportManager->setWindowTitle(QStringLiteral("Spectacle"));
-    using GrabMode = ImageGrabber::GrabMode;
-    GrabMode oldMode = exportManager->grabMode();
-    /* If the grabMode is not one of those below we need to change it to have the placeholder
-     * replaced by the window title */
-    bool changeAndRestoreGrabMode = !(oldMode == GrabMode::ActiveWindow
-        || oldMode == GrabMode::TransientWithParent || oldMode == GrabMode::WindowUnderCursor);
-    if (changeAndRestoreGrabMode) {
-       exportManager->setGrabMode(GrabMode::ActiveWindow);
+    auto lExportManager = ExportManager::instance();
+    lExportManager->setWindowTitle(QStringLiteral("Spectacle"));
+    Spectacle::CaptureMode lOldMode = lExportManager->captureMode();
+
+    // If the grabMode is not one of those below we need to change it to have the placeholder
+    // replaced by the window title
+    bool lSwitchGrabMode = !(lOldMode == Spectacle::CaptureMode::ActiveWindow ||
+                                      lOldMode == Spectacle::CaptureMode::TransientWithParent ||
+                                      lOldMode == Spectacle::CaptureMode::WindowUnderCursor);
+    if (lSwitchGrabMode) {
+       lExportManager->setCaptureMode(Spectacle::CaptureMode::ActiveWindow);
     }
-    const QString filename = exportManager->formatFilename(mSaveNameFormat->text());
-    mPreviewLabel->setText(xi18nc("@info", "<filename>%1.%2</filename>", filename, mSaveImageFormat->currentText().toLower()));
-    if (changeAndRestoreGrabMode) {
-        exportManager->setGrabMode(oldMode);
+    const QString lFileName = lExportManager->formatFilename(mSaveNameFormat->text());
+    mPreviewLabel->setText(xi18nc("@info", "<filename>%1.%2</filename>", lFileName, mSaveImageFormat->currentText().toLower()));
+    if (lSwitchGrabMode) {
+        lExportManager->setCaptureMode(lOldMode);
     }
 }
